StandardRendererConfig

Struct StandardRendererConfig 

pub struct StandardRendererConfig {
    pub usage: Option<AudioRenderUsage2>,
    pub clock: Option<ClockType>,
    pub packet_count: Option<u32>,
    /* private fields */
}

Fields

usage: Option<AudioRenderUsage2>

The usage of the audio stream.

One of ‘usage’ or ‘usage2’ is required.

clock: Option<ClockType>

The reference clock type used by the stream.

Optional. If not specified, the default reference clock provided by the renderer is used.

packet_count: Option<u32>

How many packets to use when sending data to the AudioRenderer.

Optional. If not specified, defaults to four packets.